module Backburner

  class Client < BackburnerObject

    attr_reader :raw_data

    def initialize host, port=3234
      @host = host
      @port = port
      @connection = Connection.new @host, @port
      send_client_info
      self
    end

    def connect
      @connection = Connection.new @host, @port
    end

    def disconnect
      @connection.close
    end

    def jobs
      response = @connection.jobhlist.get
      return [] if @connection.empty?
      job_handlers = response.jobh_list.job
      job_handlers = [job_handlers] unless job_handlers.kind_of?(Array)
      job_handlers.map do |job_data|
        Job.new job_data.handle, @connection
      end
    end

    private

    def generate_client_info
      @raw_data = DataObject.new
      @raw_data.client_info = {
          version: 300,
          udp_port: 0,
          controler: 0,
          system_info: {
              total_memory: total_memory,
              total_memory_f: total_memory_f,
              num_cpus: num_cpus,
              platform: platform,
              user: user,
              computer_name: computer_name,
              mac: '00E052B9A2F20000', # TODO: change to dynamic
              work_disk_space: 0,
              i_p_address: '172.50.0.170'
          }
      }
    end

    def send_client_info
      generate_client_info
      xml = @raw_data.to_xml
      @connection.clientinfo.set xml
    end

    def total_memory
      `free -b`.match(/\d+/).to_s.to_i
    end

    def total_memory_f
      total_memory.to_f
    end

    def num_cpus
      `cat /proc/cpuinfo`.split("\n\n" ).count
    end

    def platform
      `uname`.gsub(/\n/, '')
    end

    def user
      `whoami`.gsub(/\n/, '')
    end

    def computer_name
      `hostname`.gsub(/\n/, '')
    end

  end


end