require 'net/telnet'
require 'nori'

module Backburner

  class Connection

    STATUS_REGEXP = /(\d+) ([0-9A-z ]+)$/
    PROMPT_REGEXP = /\n?backburner(\(controller\))?>/i
    XML_COMMENT_REGEXP = /<!--.+-->/

    attr_reader :last_message, :last_size, :last_status, :last_body, :last_response

    def initialize host='127.0.0.1', port=3234
      @session = Net::Telnet.new('Host' => host, 'Port' => port, 'Prompt' => PROMPT_REGEXP)
      @session.waitfor 'Match' => PROMPT_REGEXP
    end

    def method_missing method_name
      RemoteCommand.new method_name, self
    end

    def close
      @session.close
    end

    def disable_prompt
      response = exec 'String' => 'set prompt off'
      return response if @last_status==201
      raise
    end

    def exec arg_hash
      xml_string = ''
      first = true
      @session.cmd arg_hash do |response|
        if first
          response =~ /(\d+) (\d*)(.*)/
          @last_status = $1.to_i
          @last_size = $2.to_i
          @last_message = $3
          first = false
          next
        end
        xml_string += response
      end

      xml_string = xml_string.sub(/backburner>$/, '')
      DataObject.new xml_string
    end

    def send_data
    end

    def cmd data
      @last_response = @session.cmd data
      parse_response
    end

    def send_text command_data, data=nil
      request = "#{command_data}"
      request_hash = {}
      if data
        request_hash['Match'] = STATUS_REGEXP
        request += "  #{data.bytesize+14}"
      end
      request_hash['String'] = request
      @last_response = @session.cmd request_hash
      parse_status
      @last_response = @session.puts data
      @last_response = @session.waitfor('Match' => STATUS_REGEXP)
      @session.waitfor 'Match' => PROMPT_REGEXP
      parse_status
    end

    def ready?
      (@last_status||0) == 251
    end

    def proceed?
      @last_status < 200 || @last_status > 299
    end

    def ready?
      @last_status == 250
    end

    def error?
      (@last_status||0) > 399
    end

    def empty?
      @last_size == 0
    end

    private

      def parse_response
        parse_status
        parse_body
        parse_object
      end

      def parse_status
        #TODO: add exception from wrong status codes
        @last_response.scan STATUS_REGEXP
        @last_status = $1.to_i
        @last_size = $2.to_i
        @last_message = $2
        raise(ConnectionError.new, @last_message) if error?
      end

      def parse_body
        @last_body = @last_response.gsub PROMPT_REGEXP, ''
        @last_body.gsub! STATUS_REGEXP, ''
        @last_body.gsub! XML_COMMENT_REGEXP, ''
      end

      def parse_object
        parser = Nori.new :convert_tags_to => lambda { |tag| tag.snakecase.to_sym }
        DataObject.new parser.parse @last_body
      end

  end

end
