module Backburner

  class Job < BackburnerObject

    JOB_STATES = [:complete, :not_started, :waiting, :suspended, :running]

    def load_raw_data
      @connection.job.get(handler)
    end

    def servers
      return [] if !@raw_data || !@raw_data.job.servers || !@raw_data.job.servers.server
      servers = @raw_data.job.servers.server.is_a?(Array) ? @raw_data.job.servers.server : [@raw_data.job.servers.server]
      servers.map do |server|
        JobServer.new server, @connection
      end
    end

    def server_time
      servers.inject(0.0) do |sum, server|
        sum += server.time
      end
    end

    def walltime
      @raw_data.job.job_info.ended - @raw_data.job.job_info.started
    rescue
      0.0
    end

    def name
      @raw_data.job.job_info.name
    end

    def handle
      @raw_data.job.job_info.job_handle
    end

    def state
      @connection.jobstate.get(handle)
      case @connection.last_size
        when 0 then :complete
        when 1 then :not_started
        when 2 then :running
        when 3 then :suspended
        when 4 then :waiting
        else :undefined
      end
    end


  end

end

#<?xml version="1.0" encoding="UTF-8" standalone="yes" ?>
#    <Job>
#<!--backburner Job Description File-->
#                               <JobInfo>
#                               <Version>300</Version>
#        <JobHandle>4294967295</JobHandle>
#<Name>8saasdfsddf18</Name>
#        <Description>*</Description>
#<JobPriority>50</JobPriority>
#        <User>igorello</User>
#<Computer>MARINA-PK</Computer>
#        <LastUpdated>2013/09/06-13:10:07:0778-05</LastUpdated>
#        <Submitted>2013/09/06-13:10:07:0778-05</Submitted>
#        <Started>0000/00/00-00:00:00:0000-00</Started>
#        <Ended>0000/00/00-00:00:00:0000-00</Ended>
#        <NumberTasks>1</NumberTasks>
#<TasksCompleted>0</TasksCompleted>
#        <Encoding>utf-8</Encoding>
#<!--Version 2013 Data-->
#<SrvLimitCount>0</SrvLimitCount>
#        <ArchiveAfterDays>No</ArchiveAfterDays>
#<DeleteAfterDays>No</DeleteAfterDays>
#        <DeleteDays>0</DeleteDays>
#<ArchiveDays>0</ArchiveDays>
#        <AssignedSrvGrp></AssignedSrvGrp>
#</JobInfo>
#    <JobFlags>
#        <Active>Yes</Active>
#<Complete>No</Complete>
#        <NonConcurrent>No</NonConcurrent>
#<NonStoppable>No</NonStoppable>
#        <IgnoreJobShare>Yes</IgnoreJobShare>
#<JobHasDependencies>No</JobHasDependencies>
#        <ZipArchive>Yes</ZipArchive>
#<LeaveInQueue>No</LeaveInQueue>
#        <ArchiveWhenDone>No</ArchiveWhenDone>
#<DeleteWhenDone>No</DeleteWhenDone>
#        <OverrideBlockingTasks>No</OverrideBlockingTasks>
#<EnableBlockingTasks>No</EnableBlockingTasks>
#    </JobFlags>
#<Archive>
#<ArchiveSize>223773</ArchiveSize>
#        <ExtractedSize>614376</ExtractedSize>
#</Archive>
#    <Plugin>
#        <PlugName>Autodesk 3ds Max 2013 (64-bit)</PlugName>
#<PlugVersion>300</PlugVersion>
#    </Plugin>
#<Alerts>
#<Enabled>0</Enabled>
#        <Failure>No</Failure>
#<Progress>No</Progress>
#        <Completion>No</Completion>
#<NthTask>0</NthTask>
#        <SendEmail>No</SendEmail>
#<IncludeSummary>No</IncludeSummary>
#        <EmailFrom></EmailFrom>
#<EmailTo></EmailTo>
#        <EmailServer></EmailServer>
#</Alerts>
#    <Servers All="Yes" />
#<DependsOn />
#    <!--Task Specific Data-->
#    <JobDetails>
#        <D3dsMaxData>
#            <MaxJob displayable="1" editable="0" displayname="Autodesk 3ds Max 2013 General" indent="0">
#                <Sequence displayable="0" editable="0">No</Sequence>
#<JobName displayable="0" editable="0">8saasdfsddf18</JobName>
#                <MaxVersion displayable="0" editable="0">2013</MaxVersion>
#<FirstFrame displayable="1" editable="0" displayname="First Frame" type="1" indent="1">0</FirstFrame>
#                <LastFrame displayable="1" editable="0" displayname="Last Frame" type="1" indent="1">0</LastFrame>
#<Step displayable="1" editable="0" displayname="Every Nth" type="1" indent="1">1</Step>
#                <Width displayable="1" editable="0" displayname="Output Width" type="1" indent="1">1800</Width>
#<Height displayable="1" editable="0" displayname="Output Height" type="1" indent="1">1350</Height>
#                <GammaCorrection displayable="1" editable="0" displayname="Gamma Correction" type="2" indent="1" yesstring="Enabled" nostring="Disabled">Yes</GammaCorrection>
#<InputGamma displayable="1" editable="0" displayname="Input Gamma" type="0" indent="1">1.000000</InputGamma>
#                <OutputGamma displayable="1" editable="0" displayname="Output Gamma" type="0" indent="1">1.000000</OutputGamma>
#<PixelAspect displayable="1" editable="0" displayname="Pixel Aspect Ratio" type="0" indent="1">1.000000</PixelAspect>
#                <OutputCamera displayable="1" editable="0" displayname="Camera" type="0" indent="1" length="40">Current view</OutputCamera>
#<REEnabled displayable="0" editable="0">Yes</REEnabled>
#                <ServerPID displayable="0" editable="0">0</ServerPID>
#<RenderPreset displayable="0" editable="0"></RenderPreset>
#                <Script displayable="1" editable="0" displayname="Pre-render Script" type="0" indent="1" displayvalue="Unknown" length="40"></Script>
#<PostRendScript displayable="1" editable="0" displayname="Post-render Script" type="0" indent="1" displayvalue="Unknown" length="40"></PostRendScript>
#                <MaxLoad displayable="0" editable="0">20</MaxLoad>
#<MaxUnload displayable="0" editable="0">10</MaxUnload>
#                <MaxRender displayable="0" editable="0">600</MaxRender>
#<RendererName displayable="1" editable="0" displayname="Renderer" type="0" indent="1" length="40">V-Ray Adv 2.30.01</RendererName>
#                <RendererClassHi displayable="0" editable="0">1941615238</RendererClassHi>
#<RendererClassLo displayable="0" editable="0">2012806412</RendererClassLo>
#                <VideoPostJob displayable="0" editable="0">No</VideoPostJob>
#<MapsIncluded displayable="0" editable="0">No</MapsIncluded>
#                <SkipExisting displayable="0" editable="0">No</SkipExisting>
#<SkipOutputTest displayable="0" editable="0">No</SkipOutputTest>
#                <DisplayVFB displayable="0" editable="0">Yes</DisplayVFB>
#<RegionRender displayable="0" editable="0">No</RegionRender>
#                <StripRender displayable="1" editable="0" displayname="Strip Render" type="2" indent="0" yesstring="Enabled" nostring="Disabled">No</StripRender>
#<StitchRender displayable="1" editable="0" displayname="Stitch Phase" type="2" indent="0" yesstring="Yes" nostring="No">No</StitchRender>
#                <StripCount displayable="1" editable="0" displayname="Strip Count" type="1" indent="1">0</StripCount>
#<StripHeight displayable="1" editable="0" displayname="Strip Height" type="1" indent="1">1350</StripHeight>
#                <StripOverlap displayable="1" editable="0" displayname="Strip Overlap" type="1" indent="1">0</StripOverlap>
#<DeleteTempStrip displayable="0" editable="0">No</DeleteTempStrip>
#                <RenderAllBatches displayable="0" editable="0">No</RenderAllBatches>
#<RenderToTexture displayable="0" editable="0">No</RenderToTexture>
#                <IsStillFrame displayable="0" editable="0">No</IsStillFrame>
#<ContinueOnError displayable="0" editable="0">No</ContinueOnError>
#            </MaxJob>
#<Scene displayable="1" editable="0" displayname="Scene Info" indent="0">
#<NumObjects displayable="1" editable="0" displayname="Objects" type="1" indent="1">0</NumObjects>
#                <NumFaces displayable="1" editable="0" displayname="Faces" type="1" indent="1">0</NumFaces>
#<NumLights displayable="1" editable="0" displayname="Lights" type="1" indent="1">0</NumLights>
#                <SceneStart displayable="1" editable="0" displayname="Scene Start" type="1" indent="1">0</SceneStart>
#<SceneEnd displayable="1" editable="0" displayname="Scene End" type="1" indent="1">0</SceneEnd>
#                <VideoColorCheck displayable="1" editable="0" displayname="Video Color Check" type="2" indent="1" yesstring="On" nostring="Off">No</VideoColorCheck>
#<TwoSided displayable="1" editable="0" displayname="Two Sided" type="2" indent="1" yesstring="On" nostring="Off">No</TwoSided>
#                <RenderHidden displayable="1" editable="0" displayname="Render Hidden" type="2" indent="1" yesstring="On" nostring="Off">No</RenderHidden>
#<RenderAtmosphere displayable="1" editable="0" displayname="Render Atmosphere" type="2" indent="1" yesstring="On" nostring="Off">Yes</RenderAtmosphere>
#                <SuperBlack displayable="1" editable="0" displayname="Super Black" type="2" indent="1" yesstring="On" nostring="Off">No</SuperBlack>
#<SerialNumbering displayable="1" editable="0" displayname="Serial Numbering" type="2" indent="1" yesstring="On" nostring="Off">No</SerialNumbering>
#                <Dither256 displayable="1" editable="0" displayname="Dither 256" type="2" indent="1" yesstring="On" nostring="Off">Yes</Dither256>
#<DitherTrueColor displayable="1" editable="0" displayname="Dither True Color" type="2" indent="1" yesstring="On" nostring="Off">Yes</DitherTrueColor>
#                <RenderFields displayable="1" editable="0" displayname="Render Fields" type="2" indent="1" yesstring="On" nostring="Off">No</RenderFields>
#<FieldOrder displayable="1" editable="0" displayname="Field Order" type="2" indent="1" yesstring="Odd First" nostring="Even First">Yes</FieldOrder>
#                <Multithread displayable="1" editable="0" displayname="Multithread" type="2" indent="1" yesstring="On" nostring="Off">Yes</Multithread>
#<RenderDisplacements displayable="1" editable="0" displayname="Displacements" type="2" indent="1" yesstring="On" nostring="Off">Yes</RenderDisplacements>
#                <RenderEffects displayable="1" editable="0" displayname="Scene Effects" type="2" indent="1" yesstring="On" nostring="Off">Yes</RenderEffects>
#<UseAreaLights displayable="1" editable="0" displayname="Use Area Lights" type="2" indent="1" yesstring="On" nostring="Off">Yes</UseAreaLights>
#                <UseAdvLight displayable="1" editable="0" displayname="Use Advanced Lighting" type="2" indent="1" yesstring="On" nostring="Off">Yes</UseAdvLight>
#<CalcAdvLight displayable="1" editable="0" displayname="Compute Advanced Lighting" type="2" indent="1" yesstring="On" nostring="Off">No</CalcAdvLight>
#            </Scene>
#<Outputs displayable="1" editable="0" displayname="Outputs" indent="0">
#<Output>
#<Name displayable="1" editable="0" displayname="Output 0" type="3" indent="1" length="40">\\\rstor1\\NFS\\renderfarm\\users\\2\\jobs\\943\\prcs\\818\\output\\\output.jpg</Name>
#                    <OutputGamma displayable="0" editable="0">0.000000</OutputGamma>
#<IsDevice displayable="0" editable="0">No</IsDevice>
#                </Output>
#</Outputs>
#            <Cameras>
#                <Camera>
#                    <Name displayable="0" editable="0">Camera001</Name>
#</Camera>
#            </Cameras>
#<RenderElements displayable="1" editable="0" displayname="Render Elements" indent="0">
#<NoneDefined displayable="1" editable="0" displayname="None Defined" type="0" indent="1" length="40"></NoneDefined>
#            </RenderElements>
#<SessionPaths displayable="1" editable="0" displayname="Alternate Paths" indent="0">
#<Path>
#<BitmapPath displayable="1" editable="0" displayname="Alternate Bitmap Path" type="3" indent="1" length="40">\\\\rstor1\\NFS\\renderfarm\\users\\2\\jobs\\943\\prcs\\818\\input\\</BitmapPath>
#                </Path>
#</SessionPaths>
#            <BitmapOptions />
#<BakeNodes />
#            <SceneStates />
#</D3dsMaxData>
#    </JobDetails>
#</Job>